@@ -1,5 +1,5 @@
 package Net::Kubernetes;
-$Net::Kubernetes::VERSION = '0.09';
+$Net::Kubernetes::VERSION = '0.10';
 use Moose;
 require Net::Kubernetes::Namespace;
 require LWP::UserAgent;
@@ -17,7 +17,7 @@ Net::Kubernetes
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 This package provides an object oriented interface to the REST API's provided by kubernetes.
 
@@ -118,6 +118,21 @@ limited to the specified namespace.
 
 =item my $resource = $kube->create_from_file(PATH_TO_FILE) (accepts either JSON or YAML files)
 
+=back
+
+=head2 The following methods are automatically deligated to the 'default' namespace.
+
+=over 1
+
+=item $ns->get_pod('my-pod-name')
+
+=item $ns->get_repllcation_controller('my-rc-name') (aliased as $ns->get_rc('my-rc-name'))
+
+=item $ns->get_service('my-servce-name')
+
+=item $ns->get_secret('my-secret-name')
+
+
 Create from file is really just a short cut around something like:
 
   my $object = YAML::LoadFile(PATH_TO_FILE);
@@ -127,6 +142,15 @@ Create from file is really just a short cut around something like:
 
 =cut
 
+has 'default_namespace' => (
+	is         => 'rw',
+	isa        => 'Net::Kubernetes::Namespace',
+	required   => 0,
+	lazy       => 1,
+	handles    => [qw(get_pod get_rc get_replication_controller get_secret get_service)],
+	builder    => '_get_default_namespace',
+);
+
 sub get_namespace {
 	my($self, $namespace) = @_;
 	if (! defined $namespace || ! length $namespace) {
@@ -144,6 +168,11 @@ sub get_namespace {
 	}
 }
 
+sub _get_default_namespace {
+	my($self) = @_;
+	return $self->get_namespace('default');
+}
+
 return 42;
 
 =head1 See Also
