@@ -1,5 +1,5 @@
 package Net::Kubernetes::Resource::Role::HasPods;
-$Net::Kubernetes::Resource::Role::HasPods::VERSION = '0.09';
+$Net::Kubernetes::Resource::Role::HasPods::VERSION = '0.10';
 use Moose::Role;
 
 =head1 NAME
@@ -8,16 +8,14 @@ Net::Kubernetes::Resource::Role::HasPods
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 Role for resource object which might "Have Pods" ... i.e. Replication Controller or Services
 
 =cut
 
-with 'Net::Kubernetes::Role::ResourceFactory';
 with 'Net::Kubernetes::Role::APIAccess';
 
-
 sub get_pods {
 	my($self) = @_;
 	my $uri = URI->new_abs("../pods", $self->path);
@@ -28,7 +26,13 @@ sub get_pods {
 		my(@pods)=();
 		foreach my $pod (@{ $pod_list->{items}}){
 			$pod->{apiVersion} = $pod_list->{apiVersion};
-			push @pods, $self->create_resource_object($pod, 'Pod');
+			my(%create_args) = %$pod;
+			$create_args{api_version} = $pod->{apiVersion};
+			$create_args{username} = $self->username if($self->username);
+			$create_args{password} = $self->password if($self->password);
+			$create_args{url} = $self->url;
+			$create_args{base_path} = $pod->{metadata}{selfLink};
+			push @pods, Net::Kubernetes::Resource::Pod->new(%create_args);
 		}
 		return wantarray ? @pods : \@pods;
 	}else{
