@@ -1,5 +1,5 @@
 package Net::Kubernetes::Role::ResourceFactory;
-$Net::Kubernetes::Role::ResourceFactory::VERSION = '0.09';
+$Net::Kubernetes::Role::ResourceFactory::VERSION = '0.10';
 use Moose::Role;
 use MooseX::Aliases;
 require Net::Kubernetes::Resource::Service;
@@ -9,11 +9,11 @@ require Net::Kubernetes::Resource::Secret;
 
 =head1 NAME
 
-Net::Kubernetes::Role::ResoruceFactory
+Net::Kubernetes::Role::ResourceFactory
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =cut
 
